pub struct EffectCell {
pub fg: Color,
pub bg: Color,
pub underline_color: Color,
pub modifier: Modifier,
pub diff_option: CellDiffOption,
pub skip: bool,
/* private fields */
}Expand description
Terminal cell type passed to CellEffect::apply.
A buffer cell
Fields
fg: ColorThe foreground color of the cell.
bg: ColorThe background color of the cell.
underline_color: ColorThe underline color of the cell.
modifier: ModifierThe modifier of the cell.
diff_option: CellDiffOptionSpecial option applied when copying (diffing) the buffer to the screen (or another buffer).
skip: booluse set_diff_option(CellDiffOption::Skip) instead
Whether the cell should be skipped when copying (diffing) the buffer to the screen.
Use CellDiffOption::Skip via set_diff_option instead.
Implementations
Sourceimpl Cell
impl Cell
Sourcepub const fn new(symbol: &'static str) -> Cell
pub const fn new(symbol: &'static str) -> Cell
Creates a new Cell with the given symbol.
This works at compile time and puts the symbol onto the stack. Fails to build when the
symbol doesn’t fit onto the stack and requires to be placed on the heap. Use
Self::default().set_symbol() in that case. See CompactString::const_new for more
details on this.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Gets the symbol of the cell.
If the cell has no symbol, returns a single space character.
Sourcepub fn merge_symbol(
&mut self,
symbol: &str,
strategy: MergeStrategy,
) -> &mut Cell
pub fn merge_symbol( &mut self, symbol: &str, strategy: MergeStrategy, ) -> &mut Cell
Merges the symbol of the cell with the one already on the cell, using the provided
MergeStrategy.
Merges Box Drawing Unicode block characters to create a single character representing their combination, useful for border collapsing. Currently limited to box drawing characters, with potential future support for others.
Merging may not be perfect due to Unicode limitations; some symbol combinations might not
produce a valid character. MergeStrategy defines how to handle such cases, e.g.,
Exact for valid merges only, or Fuzzy for close matches.
If the cell has no symbol set, it will set the symbol to the provided one rather than merging.
Example
use ratatui_core::symbols::merge::MergeStrategy;
assert_eq!(
Cell::new("┘")
.merge_symbol("┏", MergeStrategy::Exact)
.symbol(),
"╆",
);
assert_eq!(
Cell::new("╭")
.merge_symbol("┘", MergeStrategy::Fuzzy)
.symbol(),
"┼",
);Sourcepub fn set_symbol(&mut self, symbol: &str) -> &mut Cell
pub fn set_symbol(&mut self, symbol: &str) -> &mut Cell
Sets the symbol of the cell.
Sourcepub fn set_char(&mut self, ch: char) -> &mut Cell
pub fn set_char(&mut self, ch: char) -> &mut Cell
Sets the symbol of the cell to a single character.
Sourcepub const fn set_fg(&mut self, color: Color) -> &mut Cell
pub const fn set_fg(&mut self, color: Color) -> &mut Cell
Sets the foreground color of the cell.
Sourcepub const fn set_bg(&mut self, color: Color) -> &mut Cell
pub const fn set_bg(&mut self, color: Color) -> &mut Cell
Sets the background color of the cell.
Sourcepub fn set_style<S>(&mut self, style: S) -> &mut Cell
pub fn set_style<S>(&mut self, style: S) -> &mut Cell
Sets the style of the cell.
style accepts any type that is convertible to Style (e.g. Style, Color, or
your own type that implements Into<Style>).
Sourcepub const fn set_skip(&mut self, skip: bool) -> &mut Cell
👎Deprecated since 0.30.1: use set_diff_option(CellDiffOption::Skip) instead
pub const fn set_skip(&mut self, skip: bool) -> &mut Cell
use set_diff_option(CellDiffOption::Skip) instead
Sets the cell to be skipped when copying (diffing) the buffer to the screen.
This is helpful when it is necessary to prevent the buffer from overwriting a cell that is covered by an image from some terminal graphics protocol (Sixel / iTerm / Kitty …).
Sourcepub const fn set_diff_option(
&mut self,
diff_option: CellDiffOption,
) -> &mut Cell
pub const fn set_diff_option( &mut self, diff_option: CellDiffOption, ) -> &mut Cell
Sets cell CellDiffOption.
The diff options are for dealing with cells that are wider than a unit, that should always be updated, or that should not be updated at all (skip output due to preceding wider cells).